#
# spec file for package terminator
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global __requires_exclude typelib\\(Gnome\\)
Name:           terminator
Version:        2.1.3
Release:        1.5
Summary:        Store and run multiple GNOME terminals in one window
License:        GPL-2.0-only
Group:          System/X11/Terminals
URL:            https://github.com/gnome-terminator/terminator
Source:         https://github.com/gnome-terminator/terminator/releases/download/v%{version}/%{name}-%{version}.tar.gz
Patch0:         terminator-desktop.patch
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  gobject-introspection
BuildRequires:  gsettings-desktop-schemas
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  python3
BuildRequires:  python3-cairo
BuildRequires:  python3-configobj
BuildRequires:  python3-dbus-python
BuildRequires:  python3-gobject-Gdk
BuildRequires:  python3-psutil
BuildRequires:  python3-pytest
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
BuildRequires:  xvfb-run
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  typelib(Vte) = 2.91
Requires:       gsettings-desktop-schemas
Requires:       python3-cairo
Requires:       python3-configobj
Requires:       python3-dbus-python
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       python3-psutil
Requires(post): hicolor-icon-theme
Requires(postun):hicolor-icon-theme
BuildArch:      noarch

%description
Multiple GNOME terminals in one window.  This is a project to produce
an efficient way of filling a large area of screen space with
terminals. This is done by splitting the window into a resizeable
grid of terminals. As such, you can  produce a very flexible
arrangements of terminals for different tasks.

%lang_package

%prep
%autosetup -p0
# https://github.com/gnome-terminator/terminator/issues/554
sed -i 's:pytest-runner::' setup.py
# remove pointless shebangs
sed -i '/#! \?\/usr.*/d' terminatorlib/*.py

%build
python3 setup.py build

%install
python3 setup.py install --root=%{buildroot} --prefix=%{_prefix}

rm %{buildroot}/%{_datadir}/applications/%{name}.desktop

desktop-file-install --vendor="" --dir=%{buildroot}%{_datadir}/applications data/%{name}.desktop
%suse_update_desktop_file %{name}

%fdupes %{buildroot}
%find_lang %{name}

%check
xvfb-run python3 -m pytest

%files
%license COPYING
%dir %{_datadir}/icons/HighContrast
%dir %{_datadir}/icons/HighContrast/16x16
%dir %{_datadir}/icons/HighContrast/16x16/actions
%dir %{_datadir}/icons/HighContrast/16x16/apps
%dir %{_datadir}/icons/HighContrast/16x16/status
%dir %{_datadir}/icons/HighContrast/22x22
%dir %{_datadir}/icons/HighContrast/22x22/apps
%dir %{_datadir}/icons/HighContrast/24x24
%dir %{_datadir}/icons/HighContrast/24x24/apps
%dir %{_datadir}/icons/HighContrast/32x32
%dir %{_datadir}/icons/HighContrast/32x32/apps
%dir %{_datadir}/icons/HighContrast/48x48
%dir %{_datadir}/icons/HighContrast/48x48/apps
%dir %{_datadir}/icons/HighContrast/scalable
%dir %{_datadir}/icons/HighContrast/scalable/apps
%{_bindir}/%{name}*
%{_bindir}/remotinator
%{_mandir}/man1/%{name}.*
%{_mandir}/man5/%{name}_config.*
%{python3_sitelib}/terminatorlib/
%{python3_sitelib}/terminator-*.egg-info
%{_datadir}/metainfo/%{name}.metainfo.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/*/%{name}*.png
%{_datadir}/icons/hicolor/*/*/%{name}*.svg
%{_datadir}/icons/HighContrast/*/*/%{name}*.png
%{_datadir}/icons/HighContrast/*/*/%{name}*.svg
%{_datadir}/icons/hicolor/16x16/status/terminal-bell.png
%{_datadir}/icons/HighContrast/16x16/status/terminal-bell.png
%{_datadir}/pixmaps/%{name}.png
%dir %{_datadir}/%{name}/
%dir %{_datadir}/%{name}/terminatorlib
%dir %{_datadir}/%{name}/terminatorlib/themes
%dir %{_datadir}/%{name}/terminatorlib/themes/Adwaita
%dir %{_datadir}/%{name}/terminatorlib/themes/Adwaita/gtk-3.0
%dir %{_datadir}/%{name}/terminatorlib/themes/Adwaita/gtk-3.0/apps
%dir %{_datadir}/%{name}/terminatorlib/themes/Ambiance
%dir %{_datadir}/%{name}/terminatorlib/themes/Ambiance/gtk-3.0
%dir %{_datadir}/%{name}/terminatorlib/themes/Ambiance/gtk-3.0/apps
%dir %{_datadir}/%{name}/terminatorlib/themes/Breeze
%dir %{_datadir}/%{name}/terminatorlib/themes/Breeze/gtk-3.0
%dir %{_datadir}/%{name}/terminatorlib/themes/Breeze/gtk-3.0/apps
%dir %{_datadir}/%{name}/terminatorlib/themes/HighContrast
%dir %{_datadir}/%{name}/terminatorlib/themes/HighContrast/gtk-3.0
%dir %{_datadir}/%{name}/terminatorlib/themes/HighContrast/gtk-3.0/apps
%dir %{_datadir}/%{name}/terminatorlib/themes/Radiance
%dir %{_datadir}/%{name}/terminatorlib/themes/Radiance/gtk-3.0
%dir %{_datadir}/%{name}/terminatorlib/themes/Radiance/gtk-3.0/apps
%dir %{_datadir}/%{name}/terminatorlib/themes/Raleigh
%dir %{_datadir}/%{name}/terminatorlib/themes/Raleigh/gtk-3.0
%dir %{_datadir}/%{name}/terminatorlib/themes/Raleigh/gtk-3.0/apps
%{_datadir}/%{name}/terminatorlib/themes/Adwaita/gtk-3.0/apps/terminator.css
%{_datadir}/%{name}/terminatorlib/themes/Ambiance/gtk-3.0/apps/terminator.css
%{_datadir}/%{name}/terminatorlib/themes/Ambiance/gtk-3.0/apps/terminator_styling.css
%{_datadir}/%{name}/terminatorlib/themes/Breeze/gtk-3.0/apps/terminator.css
%{_datadir}/%{name}/terminatorlib/themes/HighContrast/gtk-3.0/apps/terminator.css
%{_datadir}/%{name}/terminatorlib/themes/Radiance/gtk-3.0/apps/terminator.css
%{_datadir}/%{name}/terminatorlib/themes/Radiance/gtk-3.0/apps/terminator_styling.css
%{_datadir}/%{name}/terminatorlib/themes/Raleigh/gtk-3.0/apps/terminator.css

%files lang -f %{name}.lang

%changelog
* Mon Mar 13 2023 Simon Vogl <simon.vogl@gmx.net>
- Update to version 2.1.3:
  + Full Changelog:
    https://github.com/gnome-terminator/terminator/compare/v2.1.2...v2.1.3
  + Option to set split ratio of terminals
  + Add option to set given terminal to "read only"
  + background image - respect ratio
  + Shortcut for autosplit h/v depending on active terminal size
  + Feature: Insert terminal name to terminal (for broadcast)
  + Background image drawing modes and alignment
  + Zoom on notebook even if there is only one terminal in the
    tab + keep tab position and label in notebook rotation
* Fri Nov 18 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.1.2:
  + Long overdue, thus collected a lot of changes:
    https://github.com/gnome-terminator/terminator/compare/v2.1.1...v2.1.2
  + Fix the background image loading exception handling.
  + Add new plugin for opening current directory using right mouse.
  + Cursor: make it possible to change foreground color.
  + Allow multiline commands in Custom Commands plugin.
  + Updated translations.
* Sun Oct  9 2022 John Vandenberg <jayvdb@gmail.com>
- Replace stale website URL with Github repo
- Use xvfb-run to run full test suite
* Mon Sep  5 2022 John Vandenberg <jayvdb@gmail.com>
- Remove unnecessary BuildDepends python3-devel
- Add runtime dependency python3-dbus-python
- Activate test suite with some skips
* Tue May 24 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Do not recommend lang package: the lang package has smarter
  supplements in place (package vs requested languages).
* Mon Dec 13 2021 pgajdos@suse.com
- pytest-runner is not required for build
* Sun May  9 2021 Dirk Müller <dmueller@suse.com>
- update to 2.1.1:
  - add "switch profile" command to remotinator
  - Terminal text isn't shown on lost focus of multiple tabs and hidden scroll bar
* Tue Jan 12 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 2.1.0:
  * We now read the terminator config file from XDG_CONFIG_DIRS which defaults to /etc/xdg
    Global config is possible at: /etc/xdg/terminator/config
  * Smart Copy option to clear selection after copy
  * New feature: A Separate Json file for dynamic Layouts
  * new feature: support for term://1.2.3.4/ 'links' that when clicked
    open a new terminator ssh'ed to 1.2.3.4.
  * Reimplement "unfocused dim" using overpaintin
  * Terminator now reads config file from /etc/xdg directory
- includes 2.0.1:
  * config settings lost when I cancel "Close multiple terminals" dialog
  * Feature Suggestion: Splitted screen shells based on parent
  * Release 2.0 does not have signed assets
  * Some files install to the wrong location
  * Multi tab breaks transparent background
  * make sure data/*.in files are there for distributors
  * only set clear background when background_image in config
  * fix INSTALL instructions for setuptools
- includes 2.0:
  * Culmination of more than 4 years of work
  * GTK 2 to GTK3
  * Python2 to Python3 completion
  * new base repository url
  Packaging:
  * All scripts now use #!/usr/bin/env python as shebang, when you are using
  * python3 setup.py install or similar all binary scripts should be automatically
  * modified to the correct shebang
  * Any feedback is welcome, please open an issue or join the community channels
  Enhancements
  * Bold-is-Bright option
  * Keybindings for creating group in current tab and opening preferences
  window, as well as keybinding improvements
  * Basic background image support
  * Preference to disable Ctrl + Scroll font size change
  * Fixed a bug where search was not working properly
  * Many other small fixes, see Full Changelog
- fixed bugs:
  * No (visible) context menu in sway
  * Saving a layout after changing it, it correctly updates the config file
  but does not update the UI
  * rewrap_on_resize is deprecated in vte-0.60.0
-rebase terminator-desktop.patch
* Tue Apr 21 2020 Paolo Stivanin <info@paolostivanin.com>
- update to 1.92:
  * python3 support
  * new home on github
  * fixed lots of gtk and vte related bugs
- Removed terminator-1.91-python3.patch
- Removed terminator-1.91-py3_dnd.patch
* Sat Jan 18 2020 Kristyna Streitova <kstreitova@suse.com>
- add terminator-1.91-python3.patch to add python3 support
- add terminator-1.91-py3_dnd.patch to fix url drag and drop
- add missing Requires: python3-configobj
- use python3 variants of BuildRequires, Requires and macros
- update URL (.cz -> .com)
* Mon Aug 27 2018 tchvatal@suse.com
- Add dependency on python-cairo wrt bug#1105830
* Wed Apr 18 2018 tchvatal@suse.com
- Add direct dependency on python-gobject-Gdk without it the pkg
  fails on not finding the screen
* Fri Mar 23 2018 tchvatal@suse.com
- Fix URL and format with spec-cleaner
* Wed Nov 29 2017 scabrero@suse.com
- Version update to 1.91 release:
  * No significant new features. Just minor enhancements and lots
    of fixes.
* Wed Feb  8 2017 dimstar@opensuse.org
- Filter out auto-detected typelib(Gnome) dependency. This does not
  exist on recent GNOME desktops and terminator's code can handle
  it as an optional feature (boo#1024260).
* Mon Feb  6 2017 dimstar@opensuse.org
- Fix dependency chain (auto-detection, boo#1023712):
  + Add gobject-introspection BuildRequires
  + Drop typlib-1_0-Keybinder-3_0 Requires: it is being
    auto-detected.
  + Drop vte Requires: this is provided by the library, but the
    terminator code does not interact with it directly. It uses
    the g-i bindings only.
  + Drop python-vte Requires: since the app was ported to be
    gobject introspected, the legacy python-vte is no longer
    needed.
* Tue Jan 24 2017 tchvatal@suse.com
- Version update to 1.90 release:
  * Switch to gtk3 RC release
* Tue Jan 24 2017 tchvatal@suse.com
- Version update to 1.0:
  * Few last fixes from 0.98 marking last release using gtk2
- Drop merged patch:
  * 0001-terminator-fix-RHBZ#1268289.patch
- Drop support for SLE-11
* Sat Feb 20 2016 tchvatal@suse.com
- Version update to 0.98:
  * Run the macro scriptlets for icons/desktop files
  * Adjust filelist for the current state
  * Fix few tiny rpmlint warnings
- Add patch:
  * 0001-terminator-fix-RHBZ#1268289.patch
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashisms in post/postun scripts
* Tue Sep 24 2013 rbrownccb@opensuse.org
- update to 0.97
- bug fixes incl. bnc#842059
- for details see package changelog
* Thu Mar 15 2012 saschpe@suse.de
- Some more spec cleanup
* Thu Jan 26 2012 lijewski.stefan@zabka.pl
- spec cleanup
- split languge package
- add python-keybinder recomends
* Fri Nov 18 2011 lijewski.stefan@gmail.com
- fix build on 12.1
* Thu Nov 17 2011 lijewski.stefan@gmail.com
- update to 0.96 - for details see package changelog
* Tue Apr  5 2011 lijewski.stefan@gmail.com
- fix openSUSE:Factory build missing lang files
* Mon Mar 14 2011 Stefan Lijewski <lijewski.stefan@gmail.com> 0.95
- Fix dependencies bug (bug id 679206)
* Fri Mar 11 2011 Stefan Lijewski <lijewski.stefan@gmail.com> 0.95
- Fix build bug about directories in openSuSE 11.4
* Tue Sep 21 2010 Stefan Lijewski <lijewski.stefan@gmail.com> 0.95
-initial changelog for openSuse
* Wed Mar 31 2010 Chris Jones <cmsj@tenshu.net> 0.91-1
- Update to fix some stupid release bugs in 0.90.
    Note that this specfile is untested.
* Tue Jan  5 2010 Chris Jones <cmsj@tenshu.net> 0.90-1
- Attempt to update for 0.90 pre-release.
    Note that this specfile is untested.
* Thu Jan 15 2009 Chris Jones <cmsj@tenshu.net> 0.12-1
- Remove patch application since this isn't a fedora build.
    Note that this specfile is untested.
* Mon Dec  8 2008 Ian Weller <ianweller@gmail.com> 0.11-3
- Patch version in terminatorlib/verison.py to the one we think it is
- Fix License tag
- Update post and postun scripts with one line
* Mon Dec  1 2008 Ian Weller <ianweller@gmail.com> 0.11-2
- Add BuildRequires: gettext
- Fix installation of .desktop file
- terminator-0.11-desktop.patch:
    Remove useless things
    Move to same category as gnome-terminal
- Uses spaces instead of tabs in the specfile because I can't stand tabs
* Mon Dec  1 2008 Ian Weller <ianweller@gmail.com> 0.11-1
- Update upstream
- Fix description to something useful
- Fix group
- Fix some specfile oddities
- Complete/restandardize file list
- Get rid of she-bangs in python_sitelib
  * Sat Sep 13 2008 - Max Spevack <mspevack AT redhat DOT com> 0.10
- New upstream release.
- Tried to make sure the spec file matches guidelines on Fedora wiki.
  * Fri Jul 08 2008 - chantra AatT rpm-based DdOoTt org 0.9.fc9.rb
- New upstream release
  * Sat May 17 2008 - chantra AatT rpm-based DdOoTt org 0.8.1.fc9.rb
- Initial release for Fedora 9.
